require "numru/ggraph"
require "./gphys_const_v1.2"
require './gphys_methods_v1.91'
include NumRu
include NMath

dir = ARGV[0]
iyrs = ARGV[1].to_i
iyre = ARGV[2].to_i
gcmzsfn    = ARGV[3]
gcmzsvname = ARGV[4]
obslon = ARGV[5].to_f
obslat = ARGV[6].to_f
obsfn  = ARGV[7]
obsvname = ARGV[8]
obszs  = ARGV[9].to_f

# global mean shift of Ps
psshift = 0.0
#psshift = -60.0

# gcm files
vnameps = 'Ps'
vnamet  = 'Temp'
vnamels = 'PlanetLonFromVE'


# Reading model Ps
gphysps    = GPhys::NetCDF_IO.open(dir+'/'+vnameps+".nc", vnameps )
gphysps    = gphysps.cut('lon'=>obslon).cut('lat'=>obslat)
# Reading model Temp
gphyst     = GPhys::NetCDF_IO.open(dir+'/'+vnamet +".nc", vnamet  )
gphyst     = gphyst.cut('lon'=>obslon).cut('lat'=>obslat).cut('sig'=>0.9)
# Reading model topog
gphyszs = GPhys::NetCDF_IO.open(gcmzsfn, gcmzsvname)
gphyszs = gphyszs.cut('lon'=>obslon).cut('lat'=>obslat)
gcmzs   = gphyszs.val
gcmzs   = gcmzs[0]

p 'Ps shift   : ' + psshift.to_s + ' Pa'
p 'Obs. height: ' + obszs.to_s + ' m'
p 'GCM  height: ' + gcmzs.to_s + ' m'

time = gphysps.coord('time').val
# time (hours) of gcm data used for plot
#times = time[24*669*(iyrs-1)+1]
times = time[24*669*(iyrs-1)]
#timee = time[24*669*iyre]
timee = time[24*669*iyre-1]

gphysps    = gphysps.cut('time'=>times..timee)
gphyst     = gphyst.cut('time'=>times..timee)

# shift surface pressure
gphysps    = gphysps + psshift

# modify surface pressure using hydrostatic equilibrium
scaleheight = GasRDry / Grav * gphyst
gphysps = gphysps * ( - ( obszs - gcmzs ) / scaleheight ).exp

# Reading observed surface pressure
gphysobs = GPhys::NetCDF_IO.open(obsfn, obsvname)


# Change time axis (model)
gphysls = GPhys::NetCDF_IO.open(dir+'/'+vnamels+"_rank000000.nc", vnamels)
gphysls = gphysls.cut('time'=>times..timee)

#p gphysps.val.size
#p gphysls.val.size

replace_axis( 'ls',
              gphysls.get_att('long_name'),
              gphysls.get_att('units'),
              gphysls.val,
              'time',
              gphysps )

# modify ls axis (observation)
ls = gphysobs.coord('ls').val % 360
replace_axis( 'ls',
              gphysls.get_att('long_name'),
              gphysls.get_att('units'),
              ls,
              'ls',
              gphysobs )

#DCL.gropn(1)
DCL.gropn(2)
#if ARGV.index("-ps")
#  DCL::gropn(2)
#else
#  DCL::gropn(1)
#end
#DCL.sldiv('y',3,3)
DCL.sgpset('lcntl', false)
DCL.sgpset('lfull',true)
#DCL.uzfact(0.75)
DCL.sgpset('lfprop',true)

#GGraph.set_fig('viewport'=>[0.15,0.7,0.2,0.6])
GGraph.set_fig('viewport'=>[0.15,0.7,0.2,0.6], 'window'=>[0,360,600,1100])

GGraph.set_axes('xlabelint'=>90)

#GGraph.line( gphysps, true )
GGraph.mark( gphysps, true )
GGraph.mark( gphysobs, false, 'index'=>21 )

DCL.grcls

